import React, { useState, useEffect } from 'react';
import { Form, Icon, Input, Button, DatePicker, Select, Card, Row, Col, Pagination, Alert, Radio, Tag, Tooltip, Tabs, InputNumber } from 'antd';
import moment from 'moment';
import request from '../../../../../utils/request';
import apis from '../../../../../services/apis';
import Styles from '../style.less';
import { router } from 'umi';
import ImageUpload from '../../../../../components/XForm/ImageUpload'
import Wangedit from '../../../../../components/Wangedit/Wangedit'
import TagGroup from './tags'

const { Option } = Select
const { TabPane } = Tabs;

const formItemLayout = {
  labelCol: {
    xs: { span: 24 },
    sm: { span: 2 },
  },
  wrapperCol: {
    xs: { span: 24 },
    sm: { span: 16 },
  },
};

function AddBuilding(props) {
  const { getFieldDecorator } = props.form;

  function handleSubmit(e) {
    e.preventDefault();
    props.form.validateFieldsAndScroll((err, values) => {
      if (!err) {
        console.log('Received values of form: ', values);
      }
    });
  }

  return (
        <Form {...formItemLayout} onSubmit={handleSubmit}>
          <Form.Item label="楼盘编号">
            {getFieldDecorator('code')(<Input />)}
          </Form.Item>
          <Form.Item label="楼盘名称" hasFeedback>
            {getFieldDecorator('buildingName')(<Input />)}
          </Form.Item>
          <Form.Item label="别名" hasFeedback>
            {getFieldDecorator('name')(<Input />)}
          </Form.Item>
          <Form.Item label="项目类型" hasFeedback>
            {getFieldDecorator('name')(<Input />)}
          </Form.Item>
          <Form.Item label="均价" hasFeedback>
            {getFieldDecorator('price')(<Input />)}
          </Form.Item>
          <Form.Item label="开盘时间" hasFeedback>
            {getFieldDecorator('openingDate')(<DatePicker />)}
          </Form.Item>
          <Form.Item label="电话" hasFeedback>
            {getFieldDecorator('tel')(<Input />)}
          </Form.Item>
          <Form.Item label="项目动态" hasFeedback>
            {getFieldDecorator('dynamic')(<Input />)}
          </Form.Item>
          <Form.Item label="物业类型" hasFeedback>
            {getFieldDecorator('buildingProperty')(
              <Select mode="multiple" placeholder="物业类型" style={{ width: '1016px' }}>
                <Option value="未知">未知</Option>
              </Select>,
            )}
          </Form.Item>
          <Form.Item label="销售状态" hasFeedback>
            {getFieldDecorator('marketStatus')(<Input />)}
          </Form.Item>
          <Form.Item label="标签" hasFeedback>
            {getFieldDecorator('tags')(
              <Select mode="multiple" placeholder="标签" style={{ width: '1016px' }}>
                <Option value="未知">未知</Option>
              </Select>,
            )}
          </Form.Item>
          <Form.Item label="项目主图" hasFeedback>
            {getFieldDecorator('tags')(
              <ImageUpload />,
            )}
          </Form.Item>
          <Form.Item label="地址图片" hasFeedback>
            {getFieldDecorator('tags')(
              <ImageUpload />,
            )}
          </Form.Item>
          <Form.Item label="海报底图" hasFeedback>
            {getFieldDecorator('tags')(
              <ImageUpload />,
            )}
          </Form.Item>
          <Form.Item label="排序" hasFeedback>
            {getFieldDecorator('orderNo')(<Input />)}
          </Form.Item>
          <Form.Item label="优惠信息" hasFeedback>
            {getFieldDecorator('discount')(<Input />)}
          </Form.Item>
          <Form.Item label="首页推荐" hasFeedback>
            {getFieldDecorator('isMain')(
            <Radio.Group>
              <Radio value={1}>是</Radio>
              <Radio value={2}>否</Radio>
            </Radio.Group>,
            )}
          </Form.Item>
          <Form.Item label="所在城市" hasFeedback>
            {getFieldDecorator('cityId')(
              <Select placeholder="选择城市" style={{ width: '200px' }}>
                <Option value="red">Red</Option>
              </Select>,
            )}
          </Form.Item>
          <Form.Item label="楼盘区域" hasFeedback>
            {getFieldDecorator('buildingArea')(<Input />)}
          </Form.Item>
          <Form.Item label="项目地址" hasFeedback>
            {getFieldDecorator('address')(<Input />)}
          </Form.Item>
          <Form.Item label="项目坐标" hasFeedback>
            {getFieldDecorator('coordinate')(<Input disabled />)}
          </Form.Item>
          <Form.Item label="项目地址" hasFeedback>
            {getFieldDecorator('coordinate')(<Input />)}
          </Form.Item>
          <Form.Item label="周边交通" hasFeedback>
            {getFieldDecorator('buildingArea')(
              <TagGroup />,
            )}
          </Form.Item>
          <Form.Item label="周边交通" hasFeedback>
            {getFieldDecorator('buildingMall')(
              <TagGroup />,
            )}
          </Form.Item>
          <Form.Item label="周边学校" hasFeedback>
            {getFieldDecorator('buildingEdu')(
              <TagGroup />,
            )}
          </Form.Item>
          <Form.Item label="周边医院" hasFeedback>
            {getFieldDecorator('buildingHospital')(
              <TagGroup />,
            )}
          </Form.Item>
          <Form.Item label="周边银行" hasFeedback>
            {getFieldDecorator('buildingBank')(
              <TagGroup />,
            )}
          </Form.Item>
          <Form.Item label="周边餐饮" hasFeedback>
            {getFieldDecorator('buildingRestaurant')(
              <TagGroup />,
            )}
          </Form.Item>
          <Form.Item label="绿化率" hasFeedback>
            {getFieldDecorator('greeningRate')(<Input />)}
          </Form.Item>
          <Form.Item label="容积率" hasFeedback>
            {getFieldDecorator('volumeRate')(<Input />)}
          </Form.Item>
          <Form.Item label="车位比" hasFeedback>
            {getFieldDecorator('parkingRate')(<Input />)}
          </Form.Item>
          <Form.Item label="规划户数" hasFeedback>
            {getFieldDecorator('familyNum')(<InputNumber />)}
          </Form.Item>
          <Form.Item label="物业公司" hasFeedback>
            {getFieldDecorator('serviceCompany')(<Input />)}
          </Form.Item>
          <Form.Item label="物业费" hasFeedback>
            {getFieldDecorator('serviceFee')(<Input />)}
          </Form.Item>
          <Form.Item label="装修标准" hasFeedback>
            {getFieldDecorator('decoration')(<Input />)}
          </Form.Item>
          <Form.Item label="交房时间" hasFeedback>
            {getFieldDecorator('receivedDate')(<DatePicker />)}
          </Form.Item>
          <Form.Item label="产权年限" hasFeedback>
            {getFieldDecorator('rightsYear')(<InputNumber />)}
          </Form.Item>
          <Form.Item label="预售许可证" hasFeedback>
            {getFieldDecorator('decoration')(
              <ImageUpload />,
            )}
          </Form.Item>
          <Form.Item label="项目备注" hasFeedback>
            {getFieldDecorator('remark')(
              <Wangedit />,
            )}
          </Form.Item>
          <Form.Item style={{ width: '400px', margin: 'auto', display: 'flex', justifyContent: 'space-between' }}>
            <Button type="primary" htmlType="submit">
                确定
            </Button>
            &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
            <Button onClick={() => router.go(-1)}>
                取消
            </Button>
          </Form.Item>
        </Form>
  )
}

const WrappedAddBuildingForm = Form.create({ name: 'addBuilding' })(AddBuilding);

export default WrappedAddBuildingForm
